OSSystemExtensionsWorkspaceObserver

Trait OSSystemExtensionsWorkspaceObserver 

pub unsafe trait OSSystemExtensionsWorkspaceObserver: NSObjectProtocol {
    // Provided methods
    unsafe fn systemExtensionWillBecomeEnabled(
        &self,
        system_extension_info: &OSSystemExtensionInfo,
    )
       where Self: Sized + Message { ... }
    unsafe fn systemExtensionWillBecomeDisabled(
        &self,
        system_extension_info: &OSSystemExtensionInfo,
    )
       where Self: Sized + Message { ... }
    unsafe fn systemExtensionWillBecomeInactive(
        &self,
        system_extension_info: &OSSystemExtensionInfo,
    )
       where Self: Sized + Message { ... }
}
Provided Methods

unsafe fn systemExtensionWillBecomeEnabled( &self, system_extension_info: &OSSystemExtensionInfo, )
where Self: Sized + Message,

This delegate method will be called when a system extension has been validated and allowed by the user to run.

unsafe fn systemExtensionWillBecomeDisabled( &self, system_extension_info: &OSSystemExtensionInfo, )
where Self: Sized + Message,

This delegate method will be called when the user disables an already enabled system extension, or when the system extension is first installed and is in the disabled state.

unsafe fn systemExtensionWillBecomeInactive( &self, system_extension_info: &OSSystemExtensionInfo, )
where Self: Sized + Message,

This delegate method will be called when a system extension is deactivated and is about to get uninstalled. The extension may still be running until the system is rebooted.